# Semitan
## Python Library interacting with Tan RealTime API.

A library which interact with semitan RealTime API.

## Usage

```python
stats=stations(47.21677620581732, -1.5567190467771277)
print(stats.getLocationForecast())
```
